@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import asyncio
 import signal
 import sys
@@ -465,7 +467,7 @@ class Quart(PackageStatic):
         subdomain: Optional[str] = None,
         *,
         provide_automatic_options: Optional[bool] = None,
-        strict_slashes: bool = True,
+        strict_slashes: Optional[bool] = None,
     ) -> Callable:
         """Add a route to the application.
 
@@ -531,7 +533,7 @@ class Quart(PackageStatic):
         *,
         provide_automatic_options: Optional[bool] = None,
         is_websocket: bool = False,
-        strict_slashes: bool = True,
+        strict_slashes: Optional[bool] = None,
         merge_slashes: Optional[bool] = None,
     ) -> None:
         """Add a route/url rule to the application.
@@ -624,7 +626,7 @@ class Quart(PackageStatic):
         host: Optional[str] = None,
         subdomain: Optional[str] = None,
         *,
-        strict_slashes: bool = True,
+        strict_slashes: Optional[bool] = None,
     ) -> Callable:
         """Add a websocket to the application.
 
@@ -682,7 +684,7 @@ class Quart(PackageStatic):
         host: Optional[str] = None,
         subdomain: Optional[str] = None,
         *,
-        strict_slashes: bool = True,
+        strict_slashes: Optional[bool] = None,
     ) -> None:
         """Add a websocket url rule to the application.
 
@@ -1397,7 +1399,13 @@ class Quart(PackageStatic):
         self.teardown_appcontext_funcs.append(handler)
         return handler
 
-    def register_blueprint(self, blueprint: Blueprint, url_prefix: Optional[str] = None) -> None:
+    def register_blueprint(
+        self,
+        blueprint: Blueprint,
+        url_prefix: Optional[str] = None,
+        *,
+        subdomain: Optional[str] = None,
+    ) -> None:
         """Register a blueprint on the app.
 
         This results in the blueprint's routes, error handlers
@@ -1417,7 +1425,7 @@ class Quart(PackageStatic):
         else:
             self.blueprints[blueprint.name] = blueprint
             first_registration = True
-        blueprint.register(self, first_registration, url_prefix=url_prefix)
+        blueprint.register(self, first_registration, url_prefix=url_prefix, subdomain=subdomain)
 
     def iter_blueprints(self) -> ValuesView[Blueprint]:
         """Return a iterator over the blueprints."""
