@@ -1,5 +1,8 @@
+from __future__ import annotations  # isort:skip
+
 import quart.flask_patch.app  # isort:skip
 import quart.flask_patch.globals  # isort:skip # noqa: F401
+import quart.flask_patch.testing  # isort:skip # noqa: F401
 import quart.views  # isort:skip # noqa: F401
 from quart.flask_patch._patch import patch_all  # isort:skip
 
