@@ -6,13 +6,14 @@
 try:
     from werkzeug.exceptions import HTTPException
 except ImportError:
+
     class HTTPException:  # type: ignore
         pass
 
+
 from quart import Response
 from quart.app import Quart
 
-
 old_handle_user_exception = Quart.handle_user_exception
 
 
@@ -32,10 +33,13 @@ async def new_handle_http_exception(self, error: Exception) -> Response:  # type
         handler = self._find_exception_handler(error)
         if handler is None:
             werkzeug_response = error.get_response()
-            return await self.make_response((
-                werkzeug_response.get_data(), werkzeug_response.status_code,
-                werkzeug_response.headers,
-            ))
+            return await self.make_response(
+                (
+                    werkzeug_response.get_data(),
+                    werkzeug_response.status_code,
+                    werkzeug_response.headers,
+                )
+            )
         else:
             return await handler(error)
     else:
@@ -46,4 +50,4 @@ Quart.handle_http_exception = new_handle_http_exception  # type: ignore
 
 Flask = Quart
 
-__all__ = ('Quart',)
+__all__ = ("Quart",)
